@@ -18,16 +18,17 @@
 # - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018
 # - Dimitrios Christidis <dimitrios.christidis@cern.ch>, 2018
 # - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
+# - Brandon White <bjwhite@fnal.gov>, 2019-2020
 #
 # PY3K COMPATIBLE
 
 import datetime
 
 from sqlalchemy import and_, or_, exists, not_
-from sqlalchemy.sql.expression import bindparam, text, select, false
+from sqlalchemy.sql.expression import select, false
 
 from rucio.common.utils import chunks
-from rucio.db.sqla import models
+from rucio.db.sqla import models, filter_thread_work
 from rucio.db.sqla.session import read_session, transactional_session
 
 
@@ -133,16 +134,7 @@ def list_quarantined_replicas(rse_id, limit, worker_number=None, total_workers=N
                    models.RSEFileAssociation.name == models.QuarantinedReplica.name,
                    models.RSEFileAssociation.rse_id == models.QuarantinedReplica.rse_id))
     query = query.filter(not_(stmt))
-
-    if worker_number and total_workers and total_workers - 1 > 0:
-        if session.bind.dialect.name == 'oracle':
-            bindparams = [bindparam('worker_number', worker_number - 1), bindparam('total_workers', total_workers - 1)]
-            query = query.filter(text('ORA_HASH(path, :total_workers) = :worker_number', bindparams=bindparams))
-        elif session.bind.dialect.name == 'mysql':
-            query = query.filter('mod(md5(path), %s) = %s' % (total_workers - 1, worker_number - 1))
-        elif session.bind.dialect.name == 'postgresql':
-            query = query.filter('mod(abs((\'x\'||md5(path))::bit(32)::int), %s) = %s' % (total_workers - 1, worker_number - 1))
-
+    query = filter_thread_work(session=session, query=query, total_threads=total_workers, thread_id=worker_number, hash_variable='path')
     return [{'path': path,
              'rse_id': rse_id,
              'created_at': created_at,
@@ -153,10 +145,11 @@ def list_quarantined_replicas(rse_id, limit, worker_number=None, total_workers=N
 
 
 @read_session
-def list_rses(session=None):
+def list_rses(filters=None, session=None):
     """
     List RSEs in the Quarantined Queues.
 
+    :param filters: dictionary of attributes by which the results should be filtered.
     :param session: The database session in use.
 
     :returns: a list of RSEs.
@@ -164,4 +157,8 @@ def list_rses(session=None):
     query = session.query(models.RSE.id).distinct(models.RSE.id).\
         filter(models.QuarantinedReplica.rse_id == models.RSE.id).\
         filter(models.RSE.deleted == false())
+
+    if filters and filters.get('vo'):
+        query = query.filter(getattr(models.RSE, 'vo') == filters.get('vo'))
+
     return [rse for (rse,) in query]
